#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of menu bar output of Firefox."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("<Alt>f"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "1. Right Arrow on menu bar",
    ["BRAILLE LINE:  'Firefox application Firefox Nightly frame Menu Bar tool bar Edit menu'",
     "     VISIBLE:  'Edit menu', cursor=1",
     "BRAILLE LINE:  'Firefox application Firefox Nightly frame Menu Bar tool bar Application menu bar Undo grayed\\(Ctrl\\+Z\\)'",
     "     VISIBLE:  'Undo grayed(Ctrl+Z)', cursor=1",
     "SPEECH OUTPUT: 'Edit menu.'",
     "SPEECH OUTPUT: 'Undo grayed Ctrl+Z.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Left"))
sequence.append(utils.AssertPresentationAction(
    "2. Left Arrow on menu bar",
    ["BRAILLE LINE:  'Firefox application Firefox Nightly frame Menu Bar tool bar File menu'",
     "     VISIBLE:  'File menu', cursor=1",
     "BRAILLE LINE:  'Firefox application Firefox Nightly frame Menu Bar tool bar Application menu bar New Tab\\(Ctrl\\+T\\)'",
     "     VISIBLE:  'New Tab(Ctrl+T)', cursor=1",
     "SPEECH OUTPUT: 'File menu.'",
     "SPEECH OUTPUT: 'New Tab Ctrl+T.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "3. Basic Where Am I",
    ["BRAILLE LINE:  'Firefox application Firefox Nightly frame Menu Bar tool bar Application menu bar New Tab\\(Ctrl\\+T\\)'",
     "     VISIBLE:  'New Tab(Ctrl+T)', cursor=1",
     "SPEECH OUTPUT: 'File menu'",
     "SPEECH OUTPUT: 'Menu Bar tool bar.'",
     "SPEECH OUTPUT: 'New Tab.'",
     "SPEECH OUTPUT: 'Ctrl+T.'",
     "SPEECH OUTPUT: '1 of 13.'",
     "SPEECH OUTPUT: 'T'"]))

sequence.append(KeyComboAction("Escape"))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
