#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test to verify result of entering and escaping out of a submenu."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(KeyComboAction("<Alt>f"))
sequence.append(PauseAction(3000))

sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction("w"))
sequence.append(utils.AssertPresentationAction(
    "1. Open the Wizards submenu",
    ["BRAILLE LINE:  'soffice application Wizards menu'",
     "     VISIBLE:  'soffice application Wizards menu', cursor=21",
     "BRAILLE LINE:  'soffice application File menu Letter...'",
     "     VISIBLE:  'Letter...', cursor=1",
     "SPEECH OUTPUT: 'Wizards menu.'",
     "SPEECH OUTPUT: 'Letter...'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Escape"))
sequence.append(utils.AssertPresentationAction(
    "2. Exit the Wizards submenu, which now returns you to the document",
    ["BRAILLE LINE:  'soffice application Untitled 1 - LibreOffice Writer frame'",
     "     VISIBLE:  'Untitled 1 - LibreOffice Writer ', cursor=1",
     "SPEECH OUTPUT: 'Untitled 1 - LibreOffice Writer frame'"]))

sequence.append(KeyComboAction("<Alt>F4"))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
