#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of slider output using custom program."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "1. slider Where Am I",
    ["BRAILLE LINE:  'slider application Slider frame Some slider: 0 slider'",
     "     VISIBLE:  'Some slider: 0 slider', cursor=1",
     "SPEECH OUTPUT: 'Some slider:'",
     "SPEECH OUTPUT: 'slider 0 0 percent.'",
     "SPEECH OUTPUT: 'Alt+S'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "2. Increment value",
    ["BRAILLE LINE:  'slider application Slider frame Some slider: 1 slider'",
     "     VISIBLE:  'Some slider: 1 slider', cursor=1",
     "SPEECH OUTPUT: '1'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "3. slider Where Am I",
    ["BRAILLE LINE:  'slider application Slider frame Some slider: 1 slider'",
     "     VISIBLE:  'Some slider: 1 slider', cursor=1",
     "SPEECH OUTPUT: 'Some slider:'",
     "SPEECH OUTPUT: 'slider 1 12 percent.'",
     "SPEECH OUTPUT: 'Alt+S'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Left"))
sequence.append(utils.AssertPresentationAction(
    "4. Decrement value",
    ["BRAILLE LINE:  'slider application Slider frame Some slider: 0 slider'",
     "     VISIBLE:  'Some slider: 0 slider', cursor=1",
     "SPEECH OUTPUT: '0'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "5. slider Where Am I",
    ["BRAILLE LINE:  'slider application Slider frame Some slider: 0 slider'",
     "     VISIBLE:  'Some slider: 0 slider', cursor=1",
     "SPEECH OUTPUT: 'Some slider:'",
     "SPEECH OUTPUT: 'slider 0 0 percent.'",
     "SPEECH OUTPUT: 'Alt+S'"]))

sequence.append(KeyComboAction("<Alt>F4"))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
